@@ -33,6 +33,7 @@ path_config = "/etc/uacs/"
 sender_email, email_password, receiver_email, smtp_server = "", "", "", ""
 email_smtp_port = 0
 running = True
+number_restart = 3
 
 # Colors
 HEADER = '\033[95m'
@@ -181,7 +182,6 @@ def service_down(service, verbose):
 
     # Essaye de relancer 3x le service
     # et envoie un mail si il ne redémarre pas
-    number_restart = 3
     for i in range(number_restart):
         print(f"Relaunching n°{i}/{number_restart}")
         active = os.system(f"systemctl status {service}")
@@ -208,9 +208,11 @@ def send_mail(subject, verbose):
 
     # Envoie un mail
     now = datetime.datetime.now()
-    cpu_temp = "paste <(cat /sys/class/thermal/thermal_zone*/temp) | column -s $ -t | sed 's/\(.\)..$/°C/'"
-    cpu_usage = """awk '{u=$2+$4; t=$2+$4+$5; if (NR==1){u1=u; t1=t;} else print ($2+$4-u1) * 100 / (t-t1) "%"; }' <(
-    grep 'cpu ' /proc/stat) <(sleep 1;grep 'cpu ' /proc/stat)"""
+    cpu_usage = """grep 'cpu ' /proc/stat | awk '{usage=($2+$4)*100/($2+$4+$5)} END {print usage "%"}' """
+
+    cpu_temp = "cat /sys/class/thermal/thermal_zone*/temp"
+    cpu_temp = int(os.popen(cpu_temp).read())
+    cpu_temp = "{:,}".format(cpu_temp)
 
     message = f"""\
     Subject: Oh non le service {subject} à planté !
@@ -220,8 +222,8 @@ def send_mail(subject, verbose):
     {number_restart} operation affin de le relancer ont toutes échouées
     
     Information système : 
-    CPU Temp = {os.popen(cpu_temp).read()}
-    CPU Usage = {os.popen(cpu_usage).read()}
+    CPU Temp = {os.system(cpu_temp)}
+    CPU Usage = {os.system(cpu_usage)}
     From Auto_Check_service Python Bot"""
 
     try:
